@@ -8,6 +8,7 @@ usage = ""
 min_args = 0
 
 def run(args):
+    result = 1
     message.bright('* Building')
 
     if not os.path.exists('build'):
@@ -15,11 +16,14 @@ def run(args):
 
     if subprocess.getoutput("which ninja") != '':
         cmd = 'cd build; cmake -G Ninja ..; ninja %s' % ' '.join(args)
-        os.system(cmd)
+        result = os.system(cmd)
     else:
         print(message.warn("Ninja was not found, you can consider: apt-get install ninja-build"))
         if input('Continue with Makefiles? (y/n) ') == 'y':
-            cmd = 'cd build; cmake ..; ninja %s' % ' '.join(args)
-            os.system(cmd)
+            cmd = 'cd build; cmake ..; make %s' % ' '.join(args)
+            result = os.system(cmd)
+
+    if result != 0:
+        exit(1)
 
     
